#ifndef SN_SnPreCompOptions
#define SN_SnPreCompOptions

// whether to send debugging output to the serial (usb) port
// note that this is not typically included in cpp files, so it
// may be necessary to enable more DEBUG defines in those files.
// also, the comms and peripherals packages will have their own
// separate debug switches too.
//#define DEBUG

// sorry for the double negative, but.. normally this is NOT DEFINED
// uncommenting this will allow any values to be specified in a configuration
// leaving it commented out is safer
//#define DISABLE_CONFIG_SAFETYNETS

// choose which communication peripherals will be used in the comms loop
// for now, twitter is completely not working.
#define ENABLE_AFAR_COMM
#define ENABLE_SBD_COMM
//#define ENABLE_USB_COMM
//#define ENABLE_AFAR_TWITTER

// use of the real time operating system has not been implemented
// for some time -- enabling this will not work any more.
// some development will be needed, including a RTOS aware networking package
//#define USE_RTOS // change USE_RTOS in CommConstants and EthernetPower also

// an outdated switch. currently only NetServicesMin is available.
//#define USE_ETH_INTERFACE

// turn this on to record how long it takes to take and save events
//#define EVT_TIME_PROFILE

// print the start and stop running messages on the seial (USB) port
// even if other debugging messages are disabled.
//#define SSNOTIFY

// use MODSERIAL (a buffered serial interface) instead of the
// "standard" serial (unbuffered) provided by mbed
#define USE_MODSERIAL


// available CHIPBOARDs -- these values should NEVER change!
// this is just a definition of constants. CHIPBOARD is the
// variable that must be set equal to one of these constants.
#define ATWD4CH 0  // set CHIPBOARD to this to get firmware for the 2012-2013 stations (value is arbitrary but unique)
#define SST4CH  1  // set CHIPBOARD to this to get firmware for the 2014 stations with a single SST chip (value is arbitrary but unique)

// which chip/board combination to build this firmware for
//#define CHIPBOARD ATWD4CH
#define CHIPBOARD SST4CH

// whether or not to use the flash memory on the mbed board, to call
// the mbed provided function that gets the MAC address, etc.
// these functions all use the mbed interface chip. it has been found
// that once in while, functions accessing the interface chip will block
// forever and never return, resulting in a "brain dead" station.
// therefore, this should almost certainly be disabled (commented out)
// for stations installed in the ice.
//#define USE_INTERFACE_CHIP


// whether or not to use the lookup tables to speed up the FFTs
#define USE_DFFT_LUTS

#endif // SN_SnPreCompOptions
